@@ -21,4 +21,4 @@ builtins.print = functools.partial(print, flush=True)
 from toolchest_client.api.auth import get_key, set_key
 from toolchest_client.api.exceptions import ToolchestException, DataLimitError, ToolchestJobError
 from toolchest_client.api.query import Query
-from .tools.api import bowtie2, cellranger_mkfastq, kraken2, shi7, shogun_align, shogun_filter, STAR, test, unicycler
+from .tools.api import bowtie2, cellranger_mkfastq, kraken2, megahit, shi7, shogun_align, shogun_filter, STAR, test, unicycler
